==> org-lsst-sal-camera-2.6.2-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket2_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket2_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus2_clampState;

  private final int clampxminus2_filterPositionSensorValue;

  private final int clampxminus2_filterPresenceOffset2;

  private final String clampxminus2_filterPresenceStatus;

  private final int clampxminus2_lockSensorOffset1;

  private final int clampxminus2_lockSensorValue;

  private final String clampxminus2_lockStatus;

  private final String clampxplus2_clampState;

  private final int clampxplus2_filterPositionSensorValue;

  private final int clampxplus2_filterPresenceOffset2;

  private final String clampxplus2_filterPresenceStatus;

  private final int clampxplus2_lockSensorOffset1;

  private final int clampxplus2_lockSensorValue;

  private final String clampxplus2_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final int filterID;

  private final String ioStatus;

  public Fcs_Carousel_Socket2_TrendingTelemetry(boolean atStandby, String clampxminus2_clampState,
      int clampxminus2_filterPositionSensorValue, int clampxminus2_filterPresenceOffset2,
      String clampxminus2_filterPresenceStatus, int clampxminus2_lockSensorOffset1,
      int clampxminus2_lockSensorValue, String clampxminus2_lockStatus,
      String clampxplus2_clampState, int clampxplus2_filterPositionSensorValue,
      int clampxplus2_filterPresenceOffset2, String clampxplus2_filterPresenceStatus,
      int clampxplus2_lockSensorOffset1, int clampxplus2_lockSensorValue,
      String clampxplus2_lockStatus, String clampsState, boolean empty, int filterID,
      String ioStatus) {
    this.atStandby = atStandby;
    this.clampxminus2_clampState = clampxminus2_clampState;
    this.clampxminus2_filterPositionSensorValue = clampxminus2_filterPositionSensorValue;
    this.clampxminus2_filterPresenceOffset2 = clampxminus2_filterPresenceOffset2;
    this.clampxminus2_filterPresenceStatus = clampxminus2_filterPresenceStatus;
    this.clampxminus2_lockSensorOffset1 = clampxminus2_lockSensorOffset1;
    this.clampxminus2_lockSensorValue = clampxminus2_lockSensorValue;
    this.clampxminus2_lockStatus = clampxminus2_lockStatus;
    this.clampxplus2_clampState = clampxplus2_clampState;
    this.clampxplus2_filterPositionSensorValue = clampxplus2_filterPositionSensorValue;
    this.clampxplus2_filterPresenceOffset2 = clampxplus2_filterPresenceOffset2;
    this.clampxplus2_filterPresenceStatus = clampxplus2_filterPresenceStatus;
    this.clampxplus2_lockSensorOffset1 = clampxplus2_lockSensorOffset1;
    this.clampxplus2_lockSensorValue = clampxplus2_lockSensorValue;
    this.clampxplus2_lockStatus = clampxplus2_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterID = filterID;
    this.ioStatus = ioStatus;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus2_clampState() {
    return clampxminus2_clampState;
  }

  public int getClampxminus2_filterPositionSensorValue() {
    return clampxminus2_filterPositionSensorValue;
  }

  public int getClampxminus2_filterPresenceOffset2() {
    return clampxminus2_filterPresenceOffset2;
  }

  public String getClampxminus2_filterPresenceStatus() {
    return clampxminus2_filterPresenceStatus;
  }

  public int getClampxminus2_lockSensorOffset1() {
    return clampxminus2_lockSensorOffset1;
  }

  public int getClampxminus2_lockSensorValue() {
    return clampxminus2_lockSensorValue;
  }

  public String getClampxminus2_lockStatus() {
    return clampxminus2_lockStatus;
  }

  public String getClampxplus2_clampState() {
    return clampxplus2_clampState;
  }

  public int getClampxplus2_filterPositionSensorValue() {
    return clampxplus2_filterPositionSensorValue;
  }

  public int getClampxplus2_filterPresenceOffset2() {
    return clampxplus2_filterPresenceOffset2;
  }

  public String getClampxplus2_filterPresenceStatus() {
    return clampxplus2_filterPresenceStatus;
  }

  public int getClampxplus2_lockSensorOffset1() {
    return clampxplus2_lockSensorOffset1;
  }

  public int getClampxplus2_lockSensorValue() {
    return clampxplus2_lockSensorValue;
  }

  public String getClampxplus2_lockStatus() {
    return clampxplus2_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public int getFilterID() {
    return filterID;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket2_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus2_clampState=" + clampxminus2_clampState +
        ", clampxminus2_filterPositionSensorValue=" + clampxminus2_filterPositionSensorValue +
        ", clampxminus2_filterPresenceOffset2=" + clampxminus2_filterPresenceOffset2 +
        ", clampxminus2_filterPresenceStatus=" + clampxminus2_filterPresenceStatus +
        ", clampxminus2_lockSensorOffset1=" + clampxminus2_lockSensorOffset1 +
        ", clampxminus2_lockSensorValue=" + clampxminus2_lockSensorValue +
        ", clampxminus2_lockStatus=" + clampxminus2_lockStatus +
        ", clampxplus2_clampState=" + clampxplus2_clampState +
        ", clampxplus2_filterPositionSensorValue=" + clampxplus2_filterPositionSensorValue +
        ", clampxplus2_filterPresenceOffset2=" + clampxplus2_filterPresenceOffset2 +
        ", clampxplus2_filterPresenceStatus=" + clampxplus2_filterPresenceStatus +
        ", clampxplus2_lockSensorOffset1=" + clampxplus2_lockSensorOffset1 +
        ", clampxplus2_lockSensorValue=" + clampxplus2_lockSensorValue +
        ", clampxplus2_lockStatus=" + clampxplus2_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterID=" + filterID +", ioStatus=" + ioStatus +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus2_clampState;

    private int clampxminus2_filterPositionSensorValue;

    private int clampxminus2_filterPresenceOffset2;

    private String clampxminus2_filterPresenceStatus;

    private int clampxminus2_lockSensorOffset1;

    private int clampxminus2_lockSensorValue;

    private String clampxminus2_lockStatus;

    private String clampxplus2_clampState;

    private int clampxplus2_filterPositionSensorValue;

    private int clampxplus2_filterPresenceOffset2;

    private String clampxplus2_filterPresenceStatus;

    private int clampxplus2_lockSensorOffset1;

    private int clampxplus2_lockSensorValue;

    private String clampxplus2_lockStatus;

    private String clampsState;

    private boolean empty;

    private int filterID;

    private String ioStatus;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus2_clampState(String clampxminus2_clampState) {
      this.clampxminus2_clampState = clampxminus2_clampState;
      return this;
    }

    public Builder clampxminus2_filterPositionSensorValue(
        int clampxminus2_filterPositionSensorValue) {
      this.clampxminus2_filterPositionSensorValue = clampxminus2_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus2_filterPresenceOffset2(int clampxminus2_filterPresenceOffset2) {
      this.clampxminus2_filterPresenceOffset2 = clampxminus2_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus2_filterPresenceStatus(String clampxminus2_filterPresenceStatus) {
      this.clampxminus2_filterPresenceStatus = clampxminus2_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus2_lockSensorOffset1(int clampxminus2_lockSensorOffset1) {
      this.clampxminus2_lockSensorOffset1 = clampxminus2_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus2_lockSensorValue(int clampxminus2_lockSensorValue) {
      this.clampxminus2_lockSensorValue = clampxminus2_lockSensorValue;
      return this;
    }

    public Builder clampxminus2_lockStatus(String clampxminus2_lockStatus) {
      this.clampxminus2_lockStatus = clampxminus2_lockStatus;
      return this;
    }

    public Builder clampxplus2_clampState(String clampxplus2_clampState) {
      this.clampxplus2_clampState = clampxplus2_clampState;
      return this;
    }

    public Builder clampxplus2_filterPositionSensorValue(
        int clampxplus2_filterPositionSensorValue) {
      this.clampxplus2_filterPositionSensorValue = clampxplus2_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus2_filterPresenceOffset2(int clampxplus2_filterPresenceOffset2) {
      this.clampxplus2_filterPresenceOffset2 = clampxplus2_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus2_filterPresenceStatus(String clampxplus2_filterPresenceStatus) {
      this.clampxplus2_filterPresenceStatus = clampxplus2_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus2_lockSensorOffset1(int clampxplus2_lockSensorOffset1) {
      this.clampxplus2_lockSensorOffset1 = clampxplus2_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus2_lockSensorValue(int clampxplus2_lockSensorValue) {
      this.clampxplus2_lockSensorValue = clampxplus2_lockSensorValue;
      return this;
    }

    public Builder clampxplus2_lockStatus(String clampxplus2_lockStatus) {
      this.clampxplus2_lockStatus = clampxplus2_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterID(int filterID) {
      this.filterID = filterID;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Fcs_Carousel_Socket2_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket2_TrendingTelemetry(atStandby, clampxminus2_clampState, clampxminus2_filterPositionSensorValue, clampxminus2_filterPresenceOffset2, clampxminus2_filterPresenceStatus, clampxminus2_lockSensorOffset1, clampxminus2_lockSensorValue, clampxminus2_lockStatus, clampxplus2_clampState, clampxplus2_filterPositionSensorValue, clampxplus2_filterPresenceOffset2, clampxplus2_filterPresenceStatus, clampxplus2_lockSensorOffset1, clampxplus2_lockSensorValue, clampxplus2_lockStatus, clampsState, empty, filterID, ioStatus);
    }
  }
}

==> org-lsst-sal-camera-3.0.2-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket2_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket2_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus2_clampState;

  private final int clampxminus2_filterPositionSensorValue;

  private final int clampxminus2_filterPresenceOffset2;

  private final String clampxminus2_filterPresenceStatus;

  private final int clampxminus2_lockSensorOffset1;

  private final int clampxminus2_lockSensorValue;

  private final String clampxminus2_lockStatus;

  private final String clampxplus2_clampState;

  private final int clampxplus2_filterPositionSensorValue;

  private final int clampxplus2_filterPresenceOffset2;

  private final String clampxplus2_filterPresenceStatus;

  private final int clampxplus2_lockSensorOffset1;

  private final int clampxplus2_lockSensorValue;

  private final String clampxplus2_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final String filterName;

  private final String ioStatus;

  private final int socketID;

  public Fcs_Carousel_Socket2_TrendingTelemetry(boolean atStandby, String clampxminus2_clampState,
      int clampxminus2_filterPositionSensorValue, int clampxminus2_filterPresenceOffset2,
      String clampxminus2_filterPresenceStatus, int clampxminus2_lockSensorOffset1,
      int clampxminus2_lockSensorValue, String clampxminus2_lockStatus,
      String clampxplus2_clampState, int clampxplus2_filterPositionSensorValue,
      int clampxplus2_filterPresenceOffset2, String clampxplus2_filterPresenceStatus,
      int clampxplus2_lockSensorOffset1, int clampxplus2_lockSensorValue,
      String clampxplus2_lockStatus, String clampsState, boolean empty, String filterName,
      String ioStatus, int socketID) {
    this.atStandby = atStandby;
    this.clampxminus2_clampState = clampxminus2_clampState;
    this.clampxminus2_filterPositionSensorValue = clampxminus2_filterPositionSensorValue;
    this.clampxminus2_filterPresenceOffset2 = clampxminus2_filterPresenceOffset2;
    this.clampxminus2_filterPresenceStatus = clampxminus2_filterPresenceStatus;
    this.clampxminus2_lockSensorOffset1 = clampxminus2_lockSensorOffset1;
    this.clampxminus2_lockSensorValue = clampxminus2_lockSensorValue;
    this.clampxminus2_lockStatus = clampxminus2_lockStatus;
    this.clampxplus2_clampState = clampxplus2_clampState;
    this.clampxplus2_filterPositionSensorValue = clampxplus2_filterPositionSensorValue;
    this.clampxplus2_filterPresenceOffset2 = clampxplus2_filterPresenceOffset2;
    this.clampxplus2_filterPresenceStatus = clampxplus2_filterPresenceStatus;
    this.clampxplus2_lockSensorOffset1 = clampxplus2_lockSensorOffset1;
    this.clampxplus2_lockSensorValue = clampxplus2_lockSensorValue;
    this.clampxplus2_lockStatus = clampxplus2_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterName = filterName;
    this.ioStatus = ioStatus;
    this.socketID = socketID;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus2_clampState() {
    return clampxminus2_clampState;
  }

  public int getClampxminus2_filterPositionSensorValue() {
    return clampxminus2_filterPositionSensorValue;
  }

  public int getClampxminus2_filterPresenceOffset2() {
    return clampxminus2_filterPresenceOffset2;
  }

  public String getClampxminus2_filterPresenceStatus() {
    return clampxminus2_filterPresenceStatus;
  }

  public int getClampxminus2_lockSensorOffset1() {
    return clampxminus2_lockSensorOffset1;
  }

  public int getClampxminus2_lockSensorValue() {
    return clampxminus2_lockSensorValue;
  }

  public String getClampxminus2_lockStatus() {
    return clampxminus2_lockStatus;
  }

  public String getClampxplus2_clampState() {
    return clampxplus2_clampState;
  }

  public int getClampxplus2_filterPositionSensorValue() {
    return clampxplus2_filterPositionSensorValue;
  }

  public int getClampxplus2_filterPresenceOffset2() {
    return clampxplus2_filterPresenceOffset2;
  }

  public String getClampxplus2_filterPresenceStatus() {
    return clampxplus2_filterPresenceStatus;
  }

  public int getClampxplus2_lockSensorOffset1() {
    return clampxplus2_lockSensorOffset1;
  }

  public int getClampxplus2_lockSensorValue() {
    return clampxplus2_lockSensorValue;
  }

  public String getClampxplus2_lockStatus() {
    return clampxplus2_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public String getFilterName() {
    return filterName;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  public int getSocketID() {
    return socketID;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket2_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus2_clampState=" + clampxminus2_clampState +
        ", clampxminus2_filterPositionSensorValue=" + clampxminus2_filterPositionSensorValue +
        ", clampxminus2_filterPresenceOffset2=" + clampxminus2_filterPresenceOffset2 +
        ", clampxminus2_filterPresenceStatus=" + clampxminus2_filterPresenceStatus +
        ", clampxminus2_lockSensorOffset1=" + clampxminus2_lockSensorOffset1 +
        ", clampxminus2_lockSensorValue=" + clampxminus2_lockSensorValue +
        ", clampxminus2_lockStatus=" + clampxminus2_lockStatus +
        ", clampxplus2_clampState=" + clampxplus2_clampState +
        ", clampxplus2_filterPositionSensorValue=" + clampxplus2_filterPositionSensorValue +
        ", clampxplus2_filterPresenceOffset2=" + clampxplus2_filterPresenceOffset2 +
        ", clampxplus2_filterPresenceStatus=" + clampxplus2_filterPresenceStatus +
        ", clampxplus2_lockSensorOffset1=" + clampxplus2_lockSensorOffset1 +
        ", clampxplus2_lockSensorValue=" + clampxplus2_lockSensorValue +
        ", clampxplus2_lockStatus=" + clampxplus2_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterName=" + filterName +", ioStatus=" + ioStatus +
        ", socketID=" + socketID +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus2_clampState;

    private int clampxminus2_filterPositionSensorValue;

    private int clampxminus2_filterPresenceOffset2;

    private String clampxminus2_filterPresenceStatus;

    private int clampxminus2_lockSensorOffset1;

    private int clampxminus2_lockSensorValue;

    private String clampxminus2_lockStatus;

    private String clampxplus2_clampState;

    private int clampxplus2_filterPositionSensorValue;

    private int clampxplus2_filterPresenceOffset2;

    private String clampxplus2_filterPresenceStatus;

    private int clampxplus2_lockSensorOffset1;

    private int clampxplus2_lockSensorValue;

    private String clampxplus2_lockStatus;

    private String clampsState;

    private boolean empty;

    private String filterName;

    private String ioStatus;

    private int socketID;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus2_clampState(String clampxminus2_clampState) {
      this.clampxminus2_clampState = clampxminus2_clampState;
      return this;
    }

    public Builder clampxminus2_filterPositionSensorValue(
        int clampxminus2_filterPositionSensorValue) {
      this.clampxminus2_filterPositionSensorValue = clampxminus2_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus2_filterPresenceOffset2(int clampxminus2_filterPresenceOffset2) {
      this.clampxminus2_filterPresenceOffset2 = clampxminus2_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus2_filterPresenceStatus(String clampxminus2_filterPresenceStatus) {
      this.clampxminus2_filterPresenceStatus = clampxminus2_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus2_lockSensorOffset1(int clampxminus2_lockSensorOffset1) {
      this.clampxminus2_lockSensorOffset1 = clampxminus2_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus2_lockSensorValue(int clampxminus2_lockSensorValue) {
      this.clampxminus2_lockSensorValue = clampxminus2_lockSensorValue;
      return this;
    }

    public Builder clampxminus2_lockStatus(String clampxminus2_lockStatus) {
      this.clampxminus2_lockStatus = clampxminus2_lockStatus;
      return this;
    }

    public Builder clampxplus2_clampState(String clampxplus2_clampState) {
      this.clampxplus2_clampState = clampxplus2_clampState;
      return this;
    }

    public Builder clampxplus2_filterPositionSensorValue(
        int clampxplus2_filterPositionSensorValue) {
      this.clampxplus2_filterPositionSensorValue = clampxplus2_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus2_filterPresenceOffset2(int clampxplus2_filterPresenceOffset2) {
      this.clampxplus2_filterPresenceOffset2 = clampxplus2_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus2_filterPresenceStatus(String clampxplus2_filterPresenceStatus) {
      this.clampxplus2_filterPresenceStatus = clampxplus2_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus2_lockSensorOffset1(int clampxplus2_lockSensorOffset1) {
      this.clampxplus2_lockSensorOffset1 = clampxplus2_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus2_lockSensorValue(int clampxplus2_lockSensorValue) {
      this.clampxplus2_lockSensorValue = clampxplus2_lockSensorValue;
      return this;
    }

    public Builder clampxplus2_lockStatus(String clampxplus2_lockStatus) {
      this.clampxplus2_lockStatus = clampxplus2_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterName(String filterName) {
      this.filterName = filterName;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Builder socketID(int socketID) {
      this.socketID = socketID;
      return this;
    }

    public Fcs_Carousel_Socket2_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket2_TrendingTelemetry(atStandby, clampxminus2_clampState, clampxminus2_filterPositionSensorValue, clampxminus2_filterPresenceOffset2, clampxminus2_filterPresenceStatus, clampxminus2_lockSensorOffset1, clampxminus2_lockSensorValue, clampxminus2_lockStatus, clampxplus2_clampState, clampxplus2_filterPositionSensorValue, clampxplus2_filterPresenceOffset2, clampxplus2_filterPresenceStatus, clampxplus2_lockSensorOffset1, clampxplus2_lockSensorValue, clampxplus2_lockStatus, clampsState, empty, filterName, ioStatus, socketID);
    }
  }
}
